/* A Bison parser, made by GNU Bison 2.7.  */

/* Bison interface for Yacc-like parsers in C
   
      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_SCN3YY_SQL3_H_INCLUDED
# define YY_SCN3YY_SQL3_H_INCLUDED
/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int scn3yydebug;
#endif

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NAME = 258,
     STRING = 259,
     WSTRING = 260,
     UNAME_LITERAL = 261,
     INTNUM = 262,
     IRI_LIT = 263,
     APPROXNUM = 264,
     NUM_ERROR = 265,
     AMMSC = 266,
     PARAMETER_L = 267,
     NAMED_PARAMETER = 268,
     BEGIN_EQCALL_X = 269,
     HTMLSTR = 270,
     SQL_TSI = 271,
     TIMESTAMP_FUNC = 272,
     BINARYNUM = 273,
     MSSQL_XMLCOL_NAME = 274,
     MSSQL_XMLCOL_NAME1 = 275,
     MSSQL_XMLCOL_NAMEYZ = 276,
     MSSQL_XMLCOL_NAMEZ = 277,
     MSSQL_XMLCOL_INTNUM = 278,
     TYPE = 279,
     FINAL_L = 280,
     METHOD = 281,
     CHECKED = 282,
     SYSTEM = 283,
     GENERATED = 284,
     SOURCE = 285,
     RESULT = 286,
     LOCATOR = 287,
     INSTANCE_L = 288,
     CONSTRUCTOR = 289,
     SELF_L = 290,
     OVERRIDING = 291,
     STYLE = 292,
     SQL_L = 293,
     GENERAL = 294,
     DETERMINISTIC = 295,
     NO_L = 296,
     CONTAINS = 297,
     READS = 298,
     DATA = 299,
     DISABLE_L = 300,
     NOVALIDATE_L = 301,
     ENABLE_L = 302,
     VALIDATE_L = 303,
     MODIFIES = 304,
     INPUT = 305,
     CALLED = 306,
     ADA = 307,
     C_L3 = 308,
     COBOL = 309,
     FORTRAN = 310,
     MUMPS = 311,
     PASCAL_L = 312,
     PLI = 313,
     NAME_L = 314,
     TEXT_L = 315,
     JAVA = 316,
     INOUT_L = 317,
     REMOTE = 318,
     KEYSET = 319,
     VALUE = 320,
     PARAMETER = 321,
     VARIABLE = 322,
     ADMIN_L = 323,
     ROLE_L = 324,
     TEMPORARY = 325,
     CLR = 326,
     ATTRIBUTE = 327,
     __SOAP_DOC = 328,
     __SOAP_DOCW = 329,
     __SOAP_HEADER = 330,
     __SOAP_HTTP = 331,
     __SOAP_NAME = 332,
     __SOAP_TYPE = 333,
     __SOAP_XML_TYPE = 334,
     __SOAP_FAULT = 335,
     __SOAP_DIME_ENC = 336,
     __SOAP_ENC_MIME = 337,
     __SOAP_OPTIONS = 338,
     FOREACH = 339,
     POSITION_L = 340,
     ARE = 341,
     REF = 342,
     STATIC_L = 343,
     SPECIFIC = 344,
     DYNAMIC = 345,
     COLUMN = 346,
     START_L = 347,
     __LOCK = 348,
     __TAG_L = 349,
     RDF_BOX_L = 350,
     VECTOR_L = 351,
     VECTORED = 352,
     FOR_VECTORED = 353,
     FOR_ROWS = 354,
     NOT_VECTORED = 355,
     VECTORING = 356,
     FOR = 357,
     ORDER = 358,
     EXCEPT = 359,
     UNION = 360,
     INTERSECT = 361,
     AS = 362,
     DOUBLE_COLON = 363,
     COLON = 364,
     OR = 365,
     AND = 366,
     NOT = 367,
     COMPARISON = 368,
     EQUALS = 369,
     STRING_CONCAT_OPERATOR = 370,
     UMINUS = 371,
     ALL = 372,
     ANY = 373,
     ATTACH = 374,
     ASC = 375,
     AUTHORIZATION = 376,
     BETWEEN = 377,
     BIGINT = 378,
     BREAKUP = 379,
     BY = 380,
     CASCADE = 381,
     CHARACTER = 382,
     CHECK = 383,
     CLOSE = 384,
     COMMIT = 385,
     CONSTRAINT = 386,
     CONTINUE = 387,
     CREATE = 388,
     CUBE = 389,
     CURRENT = 390,
     CURSOR = 391,
     DECIMAL_L = 392,
     DECLARE = 393,
     DEFAULT = 394,
     DELETE_L = 395,
     DESC = 396,
     DISTINCT = 397,
     DOUBLE_L = 398,
     DROP = 399,
     ESCAPE = 400,
     EXISTS = 401,
     FETCH = 402,
     FLOAT_L = 403,
     FOREIGN = 404,
     FOUND = 405,
     FROM = 406,
     GOTO = 407,
     GO = 408,
     GRANT = 409,
     GROUP = 410,
     GROUPING = 411,
     HAVING = 412,
     IN_L = 413,
     INDEX = 414,
     INDEX_NO_FILL = 415,
     INDEX_ONLY = 416,
     INDICATOR = 417,
     INSERT = 418,
     INTEGER = 419,
     INTO = 420,
     IS = 421,
     KEY = 422,
     LANGUAGE = 423,
     ENCODING = 424,
     LIKE = 425,
     NULLX = 426,
     NUMERIC = 427,
     OF = 428,
     ON = 429,
     OPEN = 430,
     OPTION = 431,
     PRECISION = 432,
     PRIMARY = 433,
     PRIVILEGES = 434,
     PROCEDURE = 435,
     PUBLIC = 436,
     REAL = 437,
     REFERENCES = 438,
     RESTRICT = 439,
     ROLLBACK = 440,
     ROLLUP = 441,
     SCHEMA = 442,
     SELECT = 443,
     SET = 444,
     SMALLINT = 445,
     SOME = 446,
     SQLCODE = 447,
     SQLERROR = 448,
     TABLE = 449,
     TO = 450,
     UNIQUE = 451,
     UPDATE = 452,
     USER = 453,
     VALUES = 454,
     VIEW = 455,
     WHENEVER = 456,
     WHERE = 457,
     WITH = 458,
     WORK = 459,
     WITHOUT_L = 460,
     ARRAY = 461,
     SETS = 462,
     CONTIGUOUS = 463,
     OBJECT_ID = 464,
     BITMAPPED = 465,
     UNDER = 466,
     CLUSTER = 467,
     __ELASTIC = 468,
     CLUSTERED = 469,
     VARCHAR = 470,
     VARBINARY = 471,
     BINARY = 472,
     LONG_L = 473,
     REPLACING = 474,
     SOFT = 475,
     HASH = 476,
     LOOP = 477,
     IRI_ID = 478,
     IRI_ID_8 = 479,
     SAME_AS = 480,
     TRANSITIVE = 481,
     QUIETCAST_L = 482,
     SPARQL_L = 483,
     UNAME_L = 484,
     SHUTDOWN = 485,
     CHECKPOINT = 486,
     BACKUP = 487,
     REPLICATION = 488,
     SYNC = 489,
     ALTER = 490,
     ADD = 491,
     RENAME = 492,
     DISCONNECT = 493,
     MODIFY = 494,
     BEFORE = 495,
     AFTER = 496,
     INSTEAD = 497,
     TRIGGER = 498,
     REFERENCING = 499,
     OLD = 500,
     AGGREGATE = 501,
     FUNCTION = 502,
     OUT_L = 503,
     HANDLER = 504,
     IF = 505,
     THEN = 506,
     ELSE = 507,
     ELSEIF = 508,
     WHILE = 509,
     BEGINX = 510,
     ENDX = 511,
     RETURN = 512,
     CALL = 513,
     RETURNS = 514,
     DO = 515,
     EXCLUSIVE = 516,
     PREFETCH = 517,
     SQLSTATE_L = 518,
     SQLWARNING = 519,
     SQLEXCEPTION = 520,
     EXIT = 521,
     RESIGNAL = 522,
     REVOKE = 523,
     PASSWORD = 524,
     OFF = 525,
     LOGX = 526,
     TIMESTAMP = 527,
     DATE_L = 528,
     DATETIME = 529,
     TIME = 530,
     EXECUTE = 531,
     REXECUTE = 532,
     MODULE = 533,
     BEGIN_FN_X = 534,
     BEGIN_CALL_X = 535,
     BEGIN_OJ_X = 536,
     BEGIN_U_X = 537,
     CONVERT = 538,
     CASE = 539,
     WHEN = 540,
     IDENTITY = 541,
     LEFT = 542,
     RIGHT = 543,
     FULL = 544,
     OUTER = 545,
     INNER = 546,
     CROSS = 547,
     NATURAL = 548,
     USING = 549,
     JOIN = 550,
     USE = 551,
     COALESCE = 552,
     CAST = 553,
     NULLIF = 554,
     NEW = 555,
     CORRESPONDING = 556,
     BEST = 557,
     TOP = 558,
     PERCENT = 559,
     TIES = 560,
     XML = 561,
     XPATH = 562,
     PERSISTENT = 563,
     INTERVAL = 564,
     INCREMENT_L = 565,
     COMPRESS = 566,
     PARTITION = 567,
     DTD = 568,
     INTERNAL = 569,
     EXTERNAL = 570,
     COLLATE = 571,
     NCHAR = 572,
     NVARCHAR = 573,
     INCREMENTAL = 574,
     NONINCREMENTAL = 575,
     PURGE = 576,
     SNAPSHOT = 577,
     IDENTIFIED = 578,
     EXTRACT = 579,
     KWD_TAG = 580,
     LEXICAL_ERROR = 581,
     CURRENT_DATE = 582,
     CURRENT_TIME = 583,
     CURRENT_TIMESTAMP = 584,
     PERMISSION_SET = 585,
     AUTOREGISTER_L = 586,
     LIBRARY_L = 587,
     ASSEMBLY_L = 588,
     SAFE_L = 589,
     UNRESTRICTED_L = 590,
     TRANSACTION_L = 591,
     ISOLATION_L = 592,
     LEVEL_L = 593,
     READ_L = 594,
     COMMITTED_L = 595,
     UNCOMMITTED_L = 596,
     REPEATABLE_L = 597,
     SERIALIZABLE_L = 598,
     T_FINAL_AS = 599,
     T_MIN = 600,
     T_MAX = 601,
     T_IN = 602,
     T_OUT = 603,
     T_SHORTEST_ONLY = 604,
     T_DISTINCT = 605,
     T_EXISTS = 606,
     T_NO_ORDER = 607,
     T_NO_CYCLES = 608,
     T_CYCLES_ONLY = 609,
     T_END_FLAG = 610,
     T_DIRECTION = 611,
     WS_WHITESPACE = 612,
     WS_SPARQL_SKIP = 613,
     WS_PRAGMA_LINE = 614,
     WS_PRAGMA_PREFIX_1 = 615,
     WS_PRAGMA_PREFIX_2 = 616,
     WS_PRAGMA_PREFIX_3 = 617,
     WS_PRAGMA_C_ESC = 618,
     WS_PGRAGMA_UTF8_ESC = 619,
     WS_PRAGMA_PL_DEBUG = 620,
     WS_PRAGMA_SRC = 621,
     WS_COMMENT_EOL = 622,
     WS_COMMENT_BEGIN = 623,
     WS_COMMENT_END = 624,
     WS_COMMENT_LONG = 625,
     __COST = 626
   };
#endif
/* Tokens.  */
#define NAME 258
#define STRING 259
#define WSTRING 260
#define UNAME_LITERAL 261
#define INTNUM 262
#define IRI_LIT 263
#define APPROXNUM 264
#define NUM_ERROR 265
#define AMMSC 266
#define PARAMETER_L 267
#define NAMED_PARAMETER 268
#define BEGIN_EQCALL_X 269
#define HTMLSTR 270
#define SQL_TSI 271
#define TIMESTAMP_FUNC 272
#define BINARYNUM 273
#define MSSQL_XMLCOL_NAME 274
#define MSSQL_XMLCOL_NAME1 275
#define MSSQL_XMLCOL_NAMEYZ 276
#define MSSQL_XMLCOL_NAMEZ 277
#define MSSQL_XMLCOL_INTNUM 278
#define TYPE 279
#define FINAL_L 280
#define METHOD 281
#define CHECKED 282
#define SYSTEM 283
#define GENERATED 284
#define SOURCE 285
#define RESULT 286
#define LOCATOR 287
#define INSTANCE_L 288
#define CONSTRUCTOR 289
#define SELF_L 290
#define OVERRIDING 291
#define STYLE 292
#define SQL_L 293
#define GENERAL 294
#define DETERMINISTIC 295
#define NO_L 296
#define CONTAINS 297
#define READS 298
#define DATA 299
#define DISABLE_L 300
#define NOVALIDATE_L 301
#define ENABLE_L 302
#define VALIDATE_L 303
#define MODIFIES 304
#define INPUT 305
#define CALLED 306
#define ADA 307
#define C_L3 308
#define COBOL 309
#define FORTRAN 310
#define MUMPS 311
#define PASCAL_L 312
#define PLI 313
#define NAME_L 314
#define TEXT_L 315
#define JAVA 316
#define INOUT_L 317
#define REMOTE 318
#define KEYSET 319
#define VALUE 320
#define PARAMETER 321
#define VARIABLE 322
#define ADMIN_L 323
#define ROLE_L 324
#define TEMPORARY 325
#define CLR 326
#define ATTRIBUTE 327
#define __SOAP_DOC 328
#define __SOAP_DOCW 329
#define __SOAP_HEADER 330
#define __SOAP_HTTP 331
#define __SOAP_NAME 332
#define __SOAP_TYPE 333
#define __SOAP_XML_TYPE 334
#define __SOAP_FAULT 335
#define __SOAP_DIME_ENC 336
#define __SOAP_ENC_MIME 337
#define __SOAP_OPTIONS 338
#define FOREACH 339
#define POSITION_L 340
#define ARE 341
#define REF 342
#define STATIC_L 343
#define SPECIFIC 344
#define DYNAMIC 345
#define COLUMN 346
#define START_L 347
#define __LOCK 348
#define __TAG_L 349
#define RDF_BOX_L 350
#define VECTOR_L 351
#define VECTORED 352
#define FOR_VECTORED 353
#define FOR_ROWS 354
#define NOT_VECTORED 355
#define VECTORING 356
#define FOR 357
#define ORDER 358
#define EXCEPT 359
#define UNION 360
#define INTERSECT 361
#define AS 362
#define DOUBLE_COLON 363
#define COLON 364
#define OR 365
#define AND 366
#define NOT 367
#define COMPARISON 368
#define EQUALS 369
#define STRING_CONCAT_OPERATOR 370
#define UMINUS 371
#define ALL 372
#define ANY 373
#define ATTACH 374
#define ASC 375
#define AUTHORIZATION 376
#define BETWEEN 377
#define BIGINT 378
#define BREAKUP 379
#define BY 380
#define CASCADE 381
#define CHARACTER 382
#define CHECK 383
#define CLOSE 384
#define COMMIT 385
#define CONSTRAINT 386
#define CONTINUE 387
#define CREATE 388
#define CUBE 389
#define CURRENT 390
#define CURSOR 391
#define DECIMAL_L 392
#define DECLARE 393
#define DEFAULT 394
#define DELETE_L 395
#define DESC 396
#define DISTINCT 397
#define DOUBLE_L 398
#define DROP 399
#define ESCAPE 400
#define EXISTS 401
#define FETCH 402
#define FLOAT_L 403
#define FOREIGN 404
#define FOUND 405
#define FROM 406
#define GOTO 407
#define GO 408
#define GRANT 409
#define GROUP 410
#define GROUPING 411
#define HAVING 412
#define IN_L 413
#define INDEX 414
#define INDEX_NO_FILL 415
#define INDEX_ONLY 416
#define INDICATOR 417
#define INSERT 418
#define INTEGER 419
#define INTO 420
#define IS 421
#define KEY 422
#define LANGUAGE 423
#define ENCODING 424
#define LIKE 425
#define NULLX 426
#define NUMERIC 427
#define OF 428
#define ON 429
#define OPEN 430
#define OPTION 431
#define PRECISION 432
#define PRIMARY 433
#define PRIVILEGES 434
#define PROCEDURE 435
#define PUBLIC 436
#define REAL 437
#define REFERENCES 438
#define RESTRICT 439
#define ROLLBACK 440
#define ROLLUP 441
#define SCHEMA 442
#define SELECT 443
#define SET 444
#define SMALLINT 445
#define SOME 446
#define SQLCODE 447
#define SQLERROR 448
#define TABLE 449
#define TO 450
#define UNIQUE 451
#define UPDATE 452
#define USER 453
#define VALUES 454
#define VIEW 455
#define WHENEVER 456
#define WHERE 457
#define WITH 458
#define WORK 459
#define WITHOUT_L 460
#define ARRAY 461
#define SETS 462
#define CONTIGUOUS 463
#define OBJECT_ID 464
#define BITMAPPED 465
#define UNDER 466
#define CLUSTER 467
#define __ELASTIC 468
#define CLUSTERED 469
#define VARCHAR 470
#define VARBINARY 471
#define BINARY 472
#define LONG_L 473
#define REPLACING 474
#define SOFT 475
#define HASH 476
#define LOOP 477
#define IRI_ID 478
#define IRI_ID_8 479
#define SAME_AS 480
#define TRANSITIVE 481
#define QUIETCAST_L 482
#define SPARQL_L 483
#define UNAME_L 484
#define SHUTDOWN 485
#define CHECKPOINT 486
#define BACKUP 487
#define REPLICATION 488
#define SYNC 489
#define ALTER 490
#define ADD 491
#define RENAME 492
#define DISCONNECT 493
#define MODIFY 494
#define BEFORE 495
#define AFTER 496
#define INSTEAD 497
#define TRIGGER 498
#define REFERENCING 499
#define OLD 500
#define AGGREGATE 501
#define FUNCTION 502
#define OUT_L 503
#define HANDLER 504
#define IF 505
#define THEN 506
#define ELSE 507
#define ELSEIF 508
#define WHILE 509
#define BEGINX 510
#define ENDX 511
#define RETURN 512
#define CALL 513
#define RETURNS 514
#define DO 515
#define EXCLUSIVE 516
#define PREFETCH 517
#define SQLSTATE_L 518
#define SQLWARNING 519
#define SQLEXCEPTION 520
#define EXIT 521
#define RESIGNAL 522
#define REVOKE 523
#define PASSWORD 524
#define OFF 525
#define LOGX 526
#define TIMESTAMP 527
#define DATE_L 528
#define DATETIME 529
#define TIME 530
#define EXECUTE 531
#define REXECUTE 532
#define MODULE 533
#define BEGIN_FN_X 534
#define BEGIN_CALL_X 535
#define BEGIN_OJ_X 536
#define BEGIN_U_X 537
#define CONVERT 538
#define CASE 539
#define WHEN 540
#define IDENTITY 541
#define LEFT 542
#define RIGHT 543
#define FULL 544
#define OUTER 545
#define INNER 546
#define CROSS 547
#define NATURAL 548
#define USING 549
#define JOIN 550
#define USE 551
#define COALESCE 552
#define CAST 553
#define NULLIF 554
#define NEW 555
#define CORRESPONDING 556
#define BEST 557
#define TOP 558
#define PERCENT 559
#define TIES 560
#define XML 561
#define XPATH 562
#define PERSISTENT 563
#define INTERVAL 564
#define INCREMENT_L 565
#define COMPRESS 566
#define PARTITION 567
#define DTD 568
#define INTERNAL 569
#define EXTERNAL 570
#define COLLATE 571
#define NCHAR 572
#define NVARCHAR 573
#define INCREMENTAL 574
#define NONINCREMENTAL 575
#define PURGE 576
#define SNAPSHOT 577
#define IDENTIFIED 578
#define EXTRACT 579
#define KWD_TAG 580
#define LEXICAL_ERROR 581
#define CURRENT_DATE 582
#define CURRENT_TIME 583
#define CURRENT_TIMESTAMP 584
#define PERMISSION_SET 585
#define AUTOREGISTER_L 586
#define LIBRARY_L 587
#define ASSEMBLY_L 588
#define SAFE_L 589
#define UNRESTRICTED_L 590
#define TRANSACTION_L 591
#define ISOLATION_L 592
#define LEVEL_L 593
#define READ_L 594
#define COMMITTED_L 595
#define UNCOMMITTED_L 596
#define REPEATABLE_L 597
#define SERIALIZABLE_L 598
#define T_FINAL_AS 599
#define T_MIN 600
#define T_MAX 601
#define T_IN 602
#define T_OUT 603
#define T_SHORTEST_ONLY 604
#define T_DISTINCT 605
#define T_EXISTS 606
#define T_NO_ORDER 607
#define T_NO_CYCLES 608
#define T_CYCLES_ONLY 609
#define T_END_FLAG 610
#define T_DIRECTION 611
#define WS_WHITESPACE 612
#define WS_SPARQL_SKIP 613
#define WS_PRAGMA_LINE 614
#define WS_PRAGMA_PREFIX_1 615
#define WS_PRAGMA_PREFIX_2 616
#define WS_PRAGMA_PREFIX_3 617
#define WS_PRAGMA_C_ESC 618
#define WS_PGRAGMA_UTF8_ESC 619
#define WS_PRAGMA_PL_DEBUG 620
#define WS_PRAGMA_SRC 621
#define WS_COMMENT_EOL 622
#define WS_COMMENT_BEGIN 623
#define WS_COMMENT_END 624
#define WS_COMMENT_LONG 625
#define __COST 626



#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{
/* Line 2058 of yacc.c  */
#line 74 "./sql3.y"

  long intval;
  char *strval;
  sql_tree_t *tree;
  caddr_t box;
  dk_set_t list;
  long subtok;
  sqlp_join_t join;


/* Line 2058 of yacc.c  */
#line 810 "sql3.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif


#ifdef YYPARSE_PARAM
#if defined __STDC__ || defined __cplusplus
int scn3yyparse (void *YYPARSE_PARAM);
#else
int scn3yyparse ();
#endif
#else /* ! YYPARSE_PARAM */
#if defined __STDC__ || defined __cplusplus
int scn3yyparse (yyscan_t scanner);
#else
int scn3yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */

#endif /* !YY_SCN3YY_SQL3_H_INCLUDED  */
